@@ -695,30 +695,13 @@ class LspGetTypeCommand(cmd.ReadOnlyCommand):
         self.result = lsp.type
 
 
-class LspSetOptionsCommand(cmd.BaseCommand):
+class LspSetOptionsCommand(cmd.BaseSetOptionsCommand):
     table = 'Logical_Switch_Port'
 
-    def __init__(self, api, port, **options):
-        super().__init__(api)
-        self.port = port
-        self.options = options
 
-    def run_idl(self, txn):
-        lsp = self.api.lookup(self.table, self.port)
-        lsp.options = self.options
-
-
-class LspGetOptionsCommand(cmd.ReadOnlyCommand):
+class LspGetOptionsCommand(cmd.BaseGetOptionsCommand):
     table = 'Logical_Switch_Port'
 
-    def __init__(self, api, port):
-        super().__init__(api)
-        self.port = port
-
-    def run_idl(self, txn):
-        lsp = self.api.lookup(self.table, self.port)
-        self.result = lsp.options
-
 
 class LspSetDhcpV4OptionsCommand(cmd.BaseCommand):
     def __init__(self, api, port, dhcpopt_uuid):
@@ -778,25 +761,12 @@ class DhcpOptionsGetCommand(cmd.BaseGetRowCommand):
     table = 'DHCP_Options'
 
 
-class DhcpOptionsSetOptionsCommand(cmd.BaseCommand):
-    def __init__(self, api, dhcpopt_uuid, **options):
-        super().__init__(api)
-        self.dhcpopt_uuid = dhcpopt_uuid
-        self.options = options
-
-    def run_idl(self, txn):
-        dhcpopt = self.api.lookup('DHCP_Options', self.dhcpopt_uuid)
-        dhcpopt.options = self.options
+class DhcpOptionsSetOptionsCommand(cmd.BaseSetOptionsCommand):
+    table = 'DHCP_Options'
 
 
-class DhcpOptionsGetOptionsCommand(cmd.ReadOnlyCommand):
-    def __init__(self, api, dhcpopt_uuid):
-        super().__init__(api)
-        self.dhcpopt_uuid = dhcpopt_uuid
-
-    def run_idl(self, txn):
-        dhcpopt = self.api.lookup('DHCP_Options', self.dhcpopt_uuid)
-        self.result = dhcpopt.options
+class DhcpOptionsGetOptionsCommand(cmd.BaseGetOptionsCommand):
+    table = 'DHCP_Options'
 
 
 class LrAddCommand(cmd.BaseCommand):
@@ -957,11 +927,11 @@ class LrpGetEnabledCommand(cmd.ReadOnlyCommand):
         self.result = next(iter(lrp.enabled), True)
 
 
-class LrpSetOptionsCommand(LspSetOptionsCommand):
+class LrpSetOptionsCommand(cmd.BaseSetOptionsCommand):
     table = 'Logical_Router_Port'
 
 
-class LrpGetOptionsCommand(LspGetOptionsCommand):
+class LrpGetOptionsCommand(cmd.BaseGetOptionsCommand):
     table = 'Logical_Router_Port'
 
 
@@ -984,7 +954,13 @@ class LrpSetGatewayChassisCommand(cmd.BaseCommand):
         lrp.addvalue('gateway_chassis', cmd.result)
 
 
-class LrpGetGatewayChassisCommand(LrpGetOptionsCommand):
+class LrpGetGatewayChassisCommand(cmd.ReadOnlyCommand):
+    table = 'Logical_Router_Port'
+
+    def __init__(self, api, port):
+        super().__init__(api)
+        self.port = port
+
     def run_idl(self, txn):
         lrp = self.api.lookup(self.table, self.port)
         self.result = [rowview.RowView(d) for d in lrp.gateway_chassis]
@@ -1012,6 +988,41 @@ class LrpDelGatewayChassisCommand(cmd.BaseCommand):
             raise RuntimeError(msg)
 
 
+class _LrpNetworksCommand(cmd.BaseCommand):
+    table = 'Logical_Router_Port'
+
+    def __init__(self, api, port, networks, exists):
+        super().__init__(api)
+        self.port = port
+        self.exists = exists
+        if isinstance(networks, (str, bytes)):
+            networks = [networks]
+        self.networks = [str(netaddr.IPNetwork(network))
+                         for network in networks]
+
+
+class LrpAddNetworksCommand(_LrpNetworksCommand):
+    def run_idl(self, txn):
+        lrp = self.api.lookup(self.table, self.port)
+        for network in self.networks:
+            if network in lrp.networks and not self.exists:
+                msg = "Network '%s' already exist in networks of port %s" % (
+                    network, lrp.uuid)
+                raise RuntimeError(msg)
+            lrp.addvalue('networks', network)
+
+
+class LrpDelNetworksCommand(_LrpNetworksCommand):
+    def run_idl(self, txn):
+        lrp = self.api.lookup(self.table, self.port)
+        for network in self.networks:
+            if network not in lrp.networks and not self.exists:
+                msg = "Network '%s' does not exist in networks of port %s" % (
+                    network, lrp.uuid)
+                raise RuntimeError(msg)
+            lrp.delvalue('networks', network)
+
+
 class LrRouteAddCommand(cmd.BaseCommand):
     def __init__(self, api, router, prefix, nexthop, port=None,
                  policy='dst-ip', may_exist=False):
@@ -1365,6 +1376,100 @@ class LbListCommand(cmd.ReadOnlyCommand):
                        for r in self.api.tables['Load_Balancer'].rows.values()]
 
 
+class LbGetCommand(cmd.BaseGetRowCommand):
+    table = 'Load_Balancer'
+
+
+class LbAddHealthCheckCommand(cmd.BaseCommand):
+    table = 'Load_Balancer'
+
+    def __init__(self, api, lb, vip, **options):
+        super().__init__(api)
+        self.lb = lb
+        self.vip = vip
+        self.options = options
+
+    def run_idl(self, txn):
+        lb = self.api.lookup(self.table, self.lb)
+        cmd = HealthCheckAddCommand(self.api, self.vip, **self.options)
+        cmd.run_idl(txn)
+        lb.addvalue('health_check', cmd.result)
+
+
+class LbDelHealthCheckCommand(cmd.BaseCommand):
+    table = 'Load_Balancer'
+
+    def __init__(self, api, lb, hc_uuid, if_exists=False):
+        super().__init__(api)
+        self.lb = lb
+        self.hc_uuid = hc_uuid
+        self.if_exists = if_exists
+
+    def run_idl(self, txn):
+        lb = self.api.lookup(self.table, self.lb)
+        for health_check in lb.health_check:
+            if health_check.uuid == self.hc_uuid:
+                lb.delvalue('health_check', health_check)
+                health_check.delete()
+                return
+        if not self.if_exists:
+            msg = "Health check '%s' on lb %s does not exist" % (
+                self.hc_uuid, self.lb)
+            raise RuntimeError(msg)
+
+
+class LbAddIpPortMappingCommand(cmd.BaseCommand):
+    table = 'Load_Balancer'
+
+    def __init__(self, api, lb, endpoint_ip, port_name, source_ip):
+        super().__init__(api)
+        self.lb = lb
+        self.endpoint_ip = str(netaddr.IPAddress(endpoint_ip))
+        self.port_name = port_name
+        self.source_ip = str(netaddr.IPAddress(source_ip))
+
+    def run_idl(self, txn):
+        lb = self.api.lookup(self.table, self.lb)
+        lb.setkey('ip_port_mappings', self.endpoint_ip,
+                  '%s:%s' % (self.port_name, self.source_ip))
+
+
+class LbDelIpPortMappingCommand(cmd.BaseCommand):
+    table = 'Load_Balancer'
+
+    def __init__(self, api, lb, endpoint_ip):
+        super().__init__(api)
+        self.lb = lb
+        self.endpoint_ip = str(netaddr.IPAddress(endpoint_ip))
+
+    def run_idl(self, txn):
+        lb = self.api.lookup(self.table, self.lb)
+        lb.delkey('ip_port_mappings', self.endpoint_ip)
+
+
+class HealthCheckAddCommand(cmd.AddCommand):
+    table_name = 'Load_Balancer_Health_Check'
+
+    def __init__(self, api, vip, **options):
+        super().__init__(api)
+        self.vip = utils.normalize_ip_port(vip)
+        self.options = options
+
+    def run_idl(self, txn):
+        hc = txn.insert(self.api.tables[self.table_name])
+        hc.vip = self.vip
+        hc.options = self.options
+        self.result = hc
+
+
+class HealthCheckSetOptionsCommand(cmd.BaseSetOptionsCommand):
+    table = 'Load_Balancer_Health_Check'
+
+
+class HealthCheckGetOptionsCommand(cmd.BaseGetOptionsCommand):
+    table = 'Load_Balancer_Health_Check'
+
+
 class LrLbAddCommand(cmd.BaseCommand):
     def __init__(self, api, router, lb, may_exist=False):
         super().__init__(api)
@@ -1699,16 +1804,15 @@ class HAChassisGroupAddChassisCommand(cmd.AddCommand):
 
     def __init__(self, api, hcg_id, chassis, priority, **columns):
         super().__init__(api)
-        self.hcg_id = hcg_id
+        self.hcg = hcg_id
         self.chassis = chassis
         self.priority = priority
         self.columns = columns
 
     def run_idl(self, txn):
-        hc_group = self.api.lookup('HA_Chassis_Group', self.hcg_id)
+        hc_group = self.api.lookup('HA_Chassis_Group', self.hcg)
         found = False
-        hc = None
-        for hc in hc_group.ha_chassis:
+        for hc in getattr(hc_group, 'ha_chassis', []):
             if hc.chassis_name != self.chassis:
                 continue
             found = True
@@ -1730,26 +1834,29 @@ class HAChassisGroupDelChassisCommand(cmd.BaseCommand):
 
     def __init__(self, api, hcg_id, chassis, if_exists=False):
         super().__init__(api)
-        self.hcg_id = hcg_id
+        self.hcg = hcg_id
         self.chassis = chassis
         self.if_exists = if_exists
 
     def run_idl(self, txn):
         try:
-            hc_group = self.api.lookup('HA_Chassis_Group', self.hcg_id)
-        except idlutils.RowNotFound:
+            hc_group = self.api.lookup('HA_Chassis_Group', self.hcg)
+        except idlutils.RowNotFound as exc:
             if self.if_exists:
                 return
 
+            raise RuntimeError('HA Chassis Group %s does not exist' %
+                               utils.get_uuid(self.hcg)) from exc
+
         hc = None
-        for hc in hc_group.ha_chassis:
+        for hc in getattr(hc_group, 'ha_chassis', []):
             if hc.chassis_name == self.chassis:
                 break
         else:
             if self.if_exists:
                 return
             raise RuntimeError(
-                'HA Chassis %s does not exist' % self.hcg_id)
+                'HA Chassis %s does not exist' % utils.get_uuid(self.hcg))
 
         hc_group.delvalue('ha_chassis', hc)
         hc.delete()
