@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 from ovsdbapp import api
 from ovsdbapp.backend.ovs_idl import idlutils
@@ -50,11 +50,19 @@ class MockRow(object):
 
 class MockCommand(api.Command):
     def __init__(self, result):
-        self.result = result
+        self._result = result
 
     def execute(self, **kwargs):
         pass
 
+    @property
+    def result(self):
+        return self._result
+
+    @result.setter
+    def result(self, value):
+        self._result = value
+
 
 class TestIdlUtils(base.TestCase):
     def test_condition_match(self):
@@ -169,3 +177,68 @@ class TestIdlUtils(base.TestCase):
                                      mock.sentinel.table_name,
                                      FAKE_RECORD_GUID)
         self.assertEqual(mock.sentinel.row_value, res)
+
+    def test_index_name(self):
+        expected = {
+            ('one',): 'one',
+            ('abc', 'def'): 'abc_def',
+            ('def', 'abc'): 'abc_def',
+            ('one', 'two', 'three'): 'one_three_two',
+        }
+        for args, result in expected.items():
+            self.assertEqual(result, idlutils.index_name(*args))
+
+        self.assertRaises(AssertionError, idlutils.index_name)
+
+
+class TestMergeIntersection(base.TestCase):
+    def test_no_args(self):
+        result = idlutils.merge_intersection()
+        # This should really be StopIteration, but there is some bug with
+        # testtools where it freaks out at getting the expected StopIteration
+        self.assertRaises((StopIteration, RuntimeError), next, result)
+
+    def test_single_empty_iterator(self):
+        result = idlutils.merge_intersection(iter([]))
+        self.assertRaises(StopIteration, next, result)
+
+    def test_multiple_empty_iterator(self):
+        result = idlutils.merge_intersection(iter([]), iter([]))
+        self.assertRaises(StopIteration, next, result)
+
+    def test_single_value_iterator(self):
+        values = [1]
+        result = idlutils.merge_intersection(iter(values))
+        self.assertEqual(values[0], next(result))
+        self.assertRaises(StopIteration, next, result)
+
+    def test_single_matching_value(self):
+        values = [[1], [1]]
+        result = idlutils.merge_intersection(*(iter(v) for v in values))
+        self.assertEqual(values[0][0], next(result))
+        self.assertRaises(StopIteration, next, result)
+
+    def test_two_matching_values(self):
+        values = [[1, 2], [1, 2]]
+        result = idlutils.merge_intersection(*(iter(v) for v in values))
+        self.assertEqual(values[0][0], next(result))
+        self.assertEqual(values[0][1], next(result))
+        self.assertRaises(StopIteration, next, result)
+
+    def test_no_overlapping_values(self):
+        values = [[0, 1], [2, 3], [4, 5]]
+        result = idlutils.merge_intersection(*(iter(v) for v in values))
+        self.assertRaises(StopIteration, next, result)
+
+    def test_proper_subset(self):
+        values = [[0, 1, 2, 3, 4], [2, 3]]
+        result = idlutils.merge_intersection(*(iter(v) for v in values))
+        self.assertEqual(2, next(result))
+        self.assertEqual(3, next(result))
+        self.assertRaises(StopIteration, next, result)
+
+    def test_intersecting_three(self):
+        values = [[1, 2, 3], [2, 3, 4], [3, 4, 5]]
+        result = idlutils.merge_intersection(*(iter(v) for v in values))
+        self.assertEqual(3, next(result))
+        self.assertRaises(StopIteration, next, result)
